Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5347)

Unified Diff: chrome/browser/ui/webui/sync_setup_handler.cc

Issue 10388169: Merge 137359 - Treat SyncCredentialsLost as an auth error (Closed) Base URL: svn://svn.chromium.org/chrome/branches/1132/src/
Patch Set: Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/sync_setup_handler.cc
===================================================================
--- chrome/browser/ui/webui/sync_setup_handler.cc (revision 137482)
+++ chrome/browser/ui/webui/sync_setup_handler.cc (working copy)
@@ -872,7 +872,7 @@
// There are several different UI flows that can bring the user here:
// 1) Signin promo (passes force_login=true)
// 2) Normal signin through options page (AreCredentialsAvailable() will
// return false).
// 3) Previously working credentials have expired
// (service->GetAuthError() != NONE).
@@ -885,7 +885,7 @@
// 7) ChromeOS re-enable after disabling sync.
#if !defined(OS_CHROMEOS)
if (force_login ||
- !service->AreCredentialsAvailable() ||
+ !service->IsSyncEnabledAndLoggedIn() ||
service->GetAuthError().state() != GoogleServiceAuthError::NONE) {
// User is not logged in, or login has been specially requested - need to
// display login UI (cases 1-4).
@@ -872,7 +872,7 @@
// There are several different UI flows that can bring the user here:
// 1) Signin promo (passes force_login=true)
- // 2) Normal signin through options page (AreCredentialsAvailable() will
+ // 2) Normal signin through options page (IsSyncEnabledAndLoggedIn() will
// return false).
// 3) Previously working credentials have expired
« no previous file with comments | « chrome/browser/ui/webui/options2/browser_options_handler2.cc ('k') | chrome/browser/ui/webui/sync_setup_handler_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698